@@ -1,4 +1,5 @@
-#define QT_FEATURE_ffmpeg 1
+#ifndef QT_FEATURES_Multimedia_src_multimedia_qtmultimedia_config_p_h_H
+#define QT_FEATURES_Multimedia_src_multimedia_qtmultimedia_config_p_h_H
 
 #define QT_FEATURE_pipewire -1
 
@@ -12,8 +13,6 @@
 
 #define QT_FEATURE_videotoolbox -1
 
-#define QT_FEATURE_evr -1
-
 #define QT_FEATURE_gstreamer 1
 
 #define QT_FEATURE_gstreamer_photography 1
@@ -38,17 +37,23 @@
 
 #define QT_FEATURE_native_android_backend -1
 
+#define QT_FEATURE_native_windows_backend -1
+
 #define QT_FEATURE_pulseaudio 1
 
-#define QT_FEATURE_wmsdk -1
-
-#define QT_FEATURE_opensles -1
+#define QT_FEATURE_aaudio -1
 
 #define QT_FEATURE_wasm -1
 
-#define QT_FEATURE_wmf -1
+#define QT_FEATURE_wasapi -1
 
 #define QT_FEATURE_spatialaudio 1
 
 #define QT_FEATURE_spatialaudio_quick3d 1
 
+#define QT_FEATURE_ffmpeg 1
+
+#define QT_FEATURE_ffmpeg_stubs -1
+
+
+#endif // QT_FEATURES_Multimedia_src_multimedia_qtmultimedia_config_p_h_H
